@@ -23,12 +23,13 @@
 #include <pthread.h>
 #endif
 
+#include "decompress.h"
 #include "ignore.h"
 #include "log.h"
 #include "options.h"
 #include "print.h"
-#include "util.h"
 #include "uthash.h"
+#include "util.h"
 
 size_t alpha_skip_lookup[256];
 size_t *find_skip_lookup;
@@ -43,7 +44,6 @@ work_queue_t *work_queue;
 work_queue_t *work_queue_tail;
 int done_adding_files;
 pthread_cond_t files_ready;
-pthread_mutex_t print_mtx;
 pthread_mutex_t stats_mtx;
 pthread_mutex_t work_queue_mtx;
 
